# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-aarch64.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-aarch64.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x12\x63ore-aarch64.proto\x1a\nopts.proto\"O\n\x17user_aarch64_regs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\n\n\x02sp\x18\x02 \x02(\x04\x12\n\n\x02pc\x18\x03 \x02(\x04\x12\x0e\n\x06pstate\x18\x04 \x02(\x04\"N\n!user_aarch64_fpsimd_context_entry\x12\r\n\x05vregs\x18\x01 \x03(\x04\x12\x0c\n\x04\x66psr\x18\x02 \x02(\r\x12\x0c\n\x04\x66pcr\x18\x03 \x02(\r\"\xa6\x01\n\x13thread_info_aarch64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12/\n\x06gpregs\x18\x03 \x02(\x0b\x32\x18.user_aarch64_regs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x06\x66psimd\x18\x04 \x02(\x0b\x32\".user_aarch64_fpsimd_context_entry')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_USER_AARCH64_REGS_ENTRY = _descriptor.Descriptor(
  name='user_aarch64_regs_entry',
  full_name='user_aarch64_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_aarch64_regs_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sp', full_name='user_aarch64_regs_entry.sp', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pc', full_name='user_aarch64_regs_entry.pc', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pstate', full_name='user_aarch64_regs_entry.pstate', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=113,
)


_USER_AARCH64_FPSIMD_CONTEXT_ENTRY = _descriptor.Descriptor(
  name='user_aarch64_fpsimd_context_entry',
  full_name='user_aarch64_fpsimd_context_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vregs', full_name='user_aarch64_fpsimd_context_entry.vregs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpsr', full_name='user_aarch64_fpsimd_context_entry.fpsr', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpcr', full_name='user_aarch64_fpsimd_context_entry.fpcr', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=193,
)


_THREAD_INFO_AARCH64 = _descriptor.Descriptor(
  name='thread_info_aarch64',
  full_name='thread_info_aarch64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_aarch64.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='thread_info_aarch64.tls', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_aarch64.gpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpsimd', full_name='thread_info_aarch64.fpsimd', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=362,
)

_THREAD_INFO_AARCH64.fields_by_name['gpregs'].message_type = _USER_AARCH64_REGS_ENTRY
_THREAD_INFO_AARCH64.fields_by_name['fpsimd'].message_type = _USER_AARCH64_FPSIMD_CONTEXT_ENTRY
DESCRIPTOR.message_types_by_name['user_aarch64_regs_entry'] = _USER_AARCH64_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_aarch64_fpsimd_context_entry'] = _USER_AARCH64_FPSIMD_CONTEXT_ENTRY
DESCRIPTOR.message_types_by_name['thread_info_aarch64'] = _THREAD_INFO_AARCH64
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_aarch64_regs_entry = _reflection.GeneratedProtocolMessageType('user_aarch64_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_AARCH64_REGS_ENTRY,
  __module__ = 'core_aarch64_pb2'
  # @@protoc_insertion_point(class_scope:user_aarch64_regs_entry)
  ))
_sym_db.RegisterMessage(user_aarch64_regs_entry)

user_aarch64_fpsimd_context_entry = _reflection.GeneratedProtocolMessageType('user_aarch64_fpsimd_context_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_AARCH64_FPSIMD_CONTEXT_ENTRY,
  __module__ = 'core_aarch64_pb2'
  # @@protoc_insertion_point(class_scope:user_aarch64_fpsimd_context_entry)
  ))
_sym_db.RegisterMessage(user_aarch64_fpsimd_context_entry)

thread_info_aarch64 = _reflection.GeneratedProtocolMessageType('thread_info_aarch64', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_AARCH64,
  __module__ = 'core_aarch64_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_aarch64)
  ))
_sym_db.RegisterMessage(thread_info_aarch64)


_THREAD_INFO_AARCH64.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_AARCH64.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_AARCH64.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_AARCH64.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\trpc.proto\"O\n\x15\x63riu_page_server_info\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\n\n\x02\x66\x64\x18\x04 \x01(\x05\"/\n\x0e\x63riu_veth_pair\x12\r\n\x05if_in\x18\x01 \x02(\t\x12\x0e\n\x06if_out\x18\x02 \x02(\t\")\n\rext_mount_map\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\x0b\n\x03val\x18\x02 \x02(\t\"@\n\x0ejoin_namespace\x12\n\n\x02ns\x18\x01 \x02(\t\x12\x0f\n\x07ns_file\x18\x02 \x02(\t\x12\x11\n\textra_opt\x18\x03 \x01(\t\"%\n\ninherit_fd\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\n\n\x02\x66\x64\x18\x02 \x02(\x05\")\n\x0b\x63group_root\x12\x0c\n\x04\x63trl\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\"\x18\n\x07unix_sk\x12\r\n\x05inode\x18\x01 \x02(\r\"\xd8\n\n\tcriu_opts\x12\x15\n\rimages_dir_fd\x18\x01 \x02(\x05\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x15\n\rleave_running\x18\x03 \x01(\x08\x12\x13\n\x0b\x65xt_unix_sk\x18\x04 \x01(\x08\x12\x17\n\x0ftcp_established\x18\x05 \x01(\x08\x12\x17\n\x0f\x65vasive_devices\x18\x06 \x01(\x08\x12\x11\n\tshell_job\x18\x07 \x01(\x08\x12\x12\n\nfile_locks\x18\x08 \x01(\x08\x12\x14\n\tlog_level\x18\t \x01(\x05:\x01\x32\x12\x10\n\x08log_file\x18\n \x01(\t\x12\"\n\x02ps\x18\x0b \x01(\x0b\x32\x16.criu_page_server_info\x12\x16\n\x0enotify_scripts\x18\x0c \x01(\x08\x12\x0c\n\x04root\x18\r \x01(\t\x12\x12\n\nparent_img\x18\x0e \x01(\t\x12\x11\n\ttrack_mem\x18\x0f \x01(\x08\x12\x12\n\nauto_dedup\x18\x10 \x01(\x08\x12\x13\n\x0bwork_dir_fd\x18\x11 \x01(\x05\x12\x12\n\nlink_remap\x18\x12 \x01(\x08\x12\x1e\n\x05veths\x18\x13 \x03(\x0b\x32\x0f.criu_veth_pair\x12\x1b\n\x07\x63pu_cap\x18\x14 \x01(\r:\n4294967295\x12\x13\n\x0b\x66orce_irmap\x18\x15 \x01(\x08\x12\x10\n\x08\x65xec_cmd\x18\x16 \x03(\t\x12\x1f\n\x07\x65xt_mnt\x18\x17 \x03(\x0b\x32\x0e.ext_mount_map\x12\x16\n\x0emanage_cgroups\x18\x18 \x01(\x08\x12\x1d\n\x07\x63g_root\x18\x19 \x03(\x0b\x32\x0c.cgroup_root\x12\x13\n\x0brst_sibling\x18\x1a \x01(\x08\x12\x1f\n\ninherit_fd\x18\x1b \x03(\x0b\x32\x0b.inherit_fd\x12\x14\n\x0c\x61uto_ext_mnt\x18\x1c \x01(\x08\x12\x13\n\x0b\x65xt_sharing\x18\x1d \x01(\x08\x12\x13\n\x0b\x65xt_masters\x18\x1e \x01(\x08\x12\x10\n\x08skip_mnt\x18\x1f \x03(\t\x12\x11\n\tenable_fs\x18  \x03(\t\x12\x1d\n\x0bunix_sk_ino\x18! \x03(\x0b\x32\x08.unix_sk\x12*\n\x13manage_cgroups_mode\x18\" \x01(\x0e\x32\r.criu_cg_mode\x12\x1c\n\x0bghost_limit\x18# \x01(\r:\x07\x31\x30\x34\x38\x35\x37\x36\x12\x18\n\x10irmap_scan_paths\x18$ \x03(\t\x12\x10\n\x08\x65xternal\x18% \x03(\t\x12\x10\n\x08\x65mpty_ns\x18& \x01(\r\x12 \n\x07join_ns\x18\' \x03(\x0b\x32\x0f.join_namespace\x12\x14\n\x0c\x63group_props\x18) \x01(\t\x12\x19\n\x11\x63group_props_file\x18* \x01(\t\x12\x1e\n\x16\x63group_dump_controller\x18+ \x03(\t\x12\x15\n\rfreeze_cgroup\x18, \x01(\t\x12\x0f\n\x07timeout\x18- \x01(\r\x12\x1a\n\x12tcp_skip_in_flight\x18. \x01(\x08\x12\x14\n\x0cweak_sysctls\x18/ \x01(\x08\x12\x12\n\nlazy_pages\x18\x30 \x01(\x08\x12\x11\n\tstatus_fd\x18\x31 \x01(\x05\x12\x19\n\x11orphan_pts_master\x18\x32 \x01(\x08\x12\x13\n\x0b\x63onfig_file\x18\x33 \x01(\t\x12\x11\n\ttcp_close\x18\x34 \x01(\x08\x12\x13\n\x0blsm_profile\x18\x35 \x01(\t\x12\x12\n\ntls_cacert\x18\x36 \x01(\t\x12\x11\n\ttls_cacrl\x18\x37 \x01(\t\x12\x10\n\x08tls_cert\x18\x38 \x01(\t\x12\x0f\n\x07tls_key\x18\x39 \x01(\t\x12\x0b\n\x03tls\x18: \x01(\x08\x12\x18\n\x10tls_no_cn_verify\x18; \x01(\x08\x12\x11\n\troot_only\x18< \x01(\x08\"\"\n\x0e\x63riu_dump_resp\x12\x10\n\x08restored\x18\x01 \x01(\x08\" \n\x11\x63riu_restore_resp\x12\x0b\n\x03pid\x18\x01 \x02(\x05\"*\n\x0b\x63riu_notify\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\"6\n\rcriu_features\x12\x11\n\tmem_track\x18\x01 \x01(\x08\x12\x12\n\nlazy_pages\x18\x02 \x01(\x08\"\x9c\x01\n\x08\x63riu_req\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x18\n\x04opts\x18\x02 \x01(\x0b\x32\n.criu_opts\x12\x16\n\x0enotify_success\x18\x03 \x01(\x08\x12\x11\n\tkeep_open\x18\x04 \x01(\x08\x12 \n\x08\x66\x65\x61tures\x18\x05 \x01(\x0b\x32\x0e.criu_features\x12\x0b\n\x03pid\x18\x06 \x01(\r\"\xb7\x02\n\tcriu_resp\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x0f\n\x07success\x18\x02 \x02(\x08\x12\x1d\n\x04\x64ump\x18\x03 \x01(\x0b\x32\x0f.criu_dump_resp\x12#\n\x07restore\x18\x04 \x01(\x0b\x32\x12.criu_restore_resp\x12\x1c\n\x06notify\x18\x05 \x01(\x0b\x32\x0c.criu_notify\x12\"\n\x02ps\x18\x06 \x01(\x0b\x32\x16.criu_page_server_info\x12\x10\n\x08\x63r_errno\x18\x07 \x01(\x05\x12 \n\x08\x66\x65\x61tures\x18\x08 \x01(\x0b\x32\x0e.criu_features\x12\x11\n\tcr_errmsg\x18\t \x01(\t\x12\x1e\n\x07version\x18\n \x01(\x0b\x32\r.criu_version\x12\x0e\n\x06status\x18\x0b \x01(\x05\"x\n\x0c\x63riu_version\x12\x14\n\x0cmajor_number\x18\x01 \x02(\x05\x12\x14\n\x0cminor_number\x18\x02 \x02(\x05\x12\r\n\x05gitid\x18\x03 \x01(\t\x12\x10\n\x08sublevel\x18\x04 \x01(\x05\x12\r\n\x05\x65xtra\x18\x05 \x01(\x05\x12\x0c\n\x04name\x18\x06 \x01(\t*_\n\x0c\x63riu_cg_mode\x12\n\n\x06IGNORE\x10\x00\x12\x0b\n\x07\x43G_NONE\x10\x01\x12\t\n\x05PROPS\x10\x02\x12\x08\n\x04SOFT\x10\x03\x12\x08\n\x04\x46ULL\x10\x04\x12\n\n\x06STRICT\x10\x05\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x06*\xd0\x01\n\rcriu_req_type\x12\t\n\x05\x45MPTY\x10\x00\x12\x08\n\x04\x44UMP\x10\x01\x12\x0b\n\x07RESTORE\x10\x02\x12\t\n\x05\x43HECK\x10\x03\x12\x0c\n\x08PRE_DUMP\x10\x04\x12\x0f\n\x0bPAGE_SERVER\x10\x05\x12\n\n\x06NOTIFY\x10\x06\x12\x10\n\x0c\x43PUINFO_DUMP\x10\x07\x12\x11\n\rCPUINFO_CHECK\x10\x08\x12\x11\n\rFEATURE_CHECK\x10\t\x12\x0b\n\x07VERSION\x10\n\x12\x0c\n\x08WAIT_PID\x10\x0b\x12\x14\n\x10PAGE_SERVER_CHLD\x10\x0c')
)

_CRIU_CG_MODE = _descriptor.EnumDescriptor(
  name='criu_cg_mode',
  full_name='criu_cg_mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CG_NONE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2496,
  serialized_end=2591,
)
_sym_db.RegisterEnumDescriptor(_CRIU_CG_MODE)

criu_cg_mode = enum_type_wrapper.EnumTypeWrapper(_CRIU_CG_MODE)
_CRIU_REQ_TYPE = _descriptor.EnumDescriptor(
  name='criu_req_type',
  full_name='criu_req_type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUMP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTORE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRE_DUMP', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE_SERVER', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTIFY', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CPUINFO_DUMP', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CPUINFO_CHECK', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_CHECK', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAIT_PID', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE_SERVER_CHLD', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2594,
  serialized_end=2802,
)
_sym_db.RegisterEnumDescriptor(_CRIU_REQ_TYPE)

criu_req_type = enum_type_wrapper.EnumTypeWrapper(_CRIU_REQ_TYPE)
IGNORE = 0
CG_NONE = 1
PROPS = 2
SOFT = 3
FULL = 4
STRICT = 5
DEFAULT = 6
EMPTY = 0
DUMP = 1
RESTORE = 2
CHECK = 3
PRE_DUMP = 4
PAGE_SERVER = 5
NOTIFY = 6
CPUINFO_DUMP = 7
CPUINFO_CHECK = 8
FEATURE_CHECK = 9
VERSION = 10
WAIT_PID = 11
PAGE_SERVER_CHLD = 12



_CRIU_PAGE_SERVER_INFO = _descriptor.Descriptor(
  name='criu_page_server_info',
  full_name='criu_page_server_info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='criu_page_server_info.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='criu_page_server_info.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_page_server_info.pid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='criu_page_server_info.fd', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=92,
)


_CRIU_VETH_PAIR = _descriptor.Descriptor(
  name='criu_veth_pair',
  full_name='criu_veth_pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='if_in', full_name='criu_veth_pair.if_in', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='if_out', full_name='criu_veth_pair.if_out', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=141,
)


_EXT_MOUNT_MAP = _descriptor.Descriptor(
  name='ext_mount_map',
  full_name='ext_mount_map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ext_mount_map.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='ext_mount_map.val', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=184,
)


_JOIN_NAMESPACE = _descriptor.Descriptor(
  name='join_namespace',
  full_name='join_namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ns', full_name='join_namespace.ns', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_file', full_name='join_namespace.ns_file', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_opt', full_name='join_namespace.extra_opt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=250,
)


_INHERIT_FD = _descriptor.Descriptor(
  name='inherit_fd',
  full_name='inherit_fd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inherit_fd.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='inherit_fd.fd', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=289,
)


_CGROUP_ROOT = _descriptor.Descriptor(
  name='cgroup_root',
  full_name='cgroup_root',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ctrl', full_name='cgroup_root.ctrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='cgroup_root.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=332,
)


_UNIX_SK = _descriptor.Descriptor(
  name='unix_sk',
  full_name='unix_sk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inode', full_name='unix_sk.inode', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=358,
)


_CRIU_OPTS = _descriptor.Descriptor(
  name='criu_opts',
  full_name='criu_opts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images_dir_fd', full_name='criu_opts.images_dir_fd', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_opts.pid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leave_running', full_name='criu_opts.leave_running', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_unix_sk', full_name='criu_opts.ext_unix_sk', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_established', full_name='criu_opts.tcp_established', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evasive_devices', full_name='criu_opts.evasive_devices', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shell_job', full_name='criu_opts.shell_job', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_locks', full_name='criu_opts.file_locks', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='criu_opts.log_level', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_file', full_name='criu_opts.log_file', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps', full_name='criu_opts.ps', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify_scripts', full_name='criu_opts.notify_scripts', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='criu_opts.root', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_img', full_name='criu_opts.parent_img', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='track_mem', full_name='criu_opts.track_mem', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_dedup', full_name='criu_opts.auto_dedup', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='work_dir_fd', full_name='criu_opts.work_dir_fd', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link_remap', full_name='criu_opts.link_remap', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='veths', full_name='criu_opts.veths', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_cap', full_name='criu_opts.cpu_cap', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_irmap', full_name='criu_opts.force_irmap', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_cmd', full_name='criu_opts.exec_cmd', index=21,
      number=22, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_mnt', full_name='criu_opts.ext_mnt', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manage_cgroups', full_name='criu_opts.manage_cgroups', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cg_root', full_name='criu_opts.cg_root', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rst_sibling', full_name='criu_opts.rst_sibling', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inherit_fd', full_name='criu_opts.inherit_fd', index=26,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_ext_mnt', full_name='criu_opts.auto_ext_mnt', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_sharing', full_name='criu_opts.ext_sharing', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_masters', full_name='criu_opts.ext_masters', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skip_mnt', full_name='criu_opts.skip_mnt', index=30,
      number=31, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_fs', full_name='criu_opts.enable_fs', index=31,
      number=32, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unix_sk_ino', full_name='criu_opts.unix_sk_ino', index=32,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manage_cgroups_mode', full_name='criu_opts.manage_cgroups_mode', index=33,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ghost_limit', full_name='criu_opts.ghost_limit', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1048576,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irmap_scan_paths', full_name='criu_opts.irmap_scan_paths', index=35,
      number=36, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external', full_name='criu_opts.external', index=36,
      number=37, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty_ns', full_name='criu_opts.empty_ns', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join_ns', full_name='criu_opts.join_ns', index=38,
      number=39, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_props', full_name='criu_opts.cgroup_props', index=39,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_props_file', full_name='criu_opts.cgroup_props_file', index=40,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_dump_controller', full_name='criu_opts.cgroup_dump_controller', index=41,
      number=43, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeze_cgroup', full_name='criu_opts.freeze_cgroup', index=42,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='criu_opts.timeout', index=43,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_skip_in_flight', full_name='criu_opts.tcp_skip_in_flight', index=44,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weak_sysctls', full_name='criu_opts.weak_sysctls', index=45,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy_pages', full_name='criu_opts.lazy_pages', index=46,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_fd', full_name='criu_opts.status_fd', index=47,
      number=49, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orphan_pts_master', full_name='criu_opts.orphan_pts_master', index=48,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_file', full_name='criu_opts.config_file', index=49,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_close', full_name='criu_opts.tcp_close', index=50,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lsm_profile', full_name='criu_opts.lsm_profile', index=51,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cacert', full_name='criu_opts.tls_cacert', index=52,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cacrl', full_name='criu_opts.tls_cacrl', index=53,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cert', full_name='criu_opts.tls_cert', index=54,
      number=56, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_key', full_name='criu_opts.tls_key', index=55,
      number=57, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='criu_opts.tls', index=56,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_no_cn_verify', full_name='criu_opts.tls_no_cn_verify', index=57,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_only', full_name='criu_opts.root_only', index=58,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=1729,
)


_CRIU_DUMP_RESP = _descriptor.Descriptor(
  name='criu_dump_resp',
  full_name='criu_dump_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='restored', full_name='criu_dump_resp.restored', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1731,
  serialized_end=1765,
)


_CRIU_RESTORE_RESP = _descriptor.Descriptor(
  name='criu_restore_resp',
  full_name='criu_restore_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_restore_resp.pid', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1767,
  serialized_end=1799,
)


_CRIU_NOTIFY = _descriptor.Descriptor(
  name='criu_notify',
  full_name='criu_notify',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='criu_notify.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_notify.pid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1801,
  serialized_end=1843,
)


_CRIU_FEATURES = _descriptor.Descriptor(
  name='criu_features',
  full_name='criu_features',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mem_track', full_name='criu_features.mem_track', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy_pages', full_name='criu_features.lazy_pages', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1845,
  serialized_end=1899,
)


_CRIU_REQ = _descriptor.Descriptor(
  name='criu_req',
  full_name='criu_req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='criu_req.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='criu_req.opts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify_success', full_name='criu_req.notify_success', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='criu_req.keep_open', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='criu_req.features', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_req.pid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2058,
)


_CRIU_RESP = _descriptor.Descriptor(
  name='criu_resp',
  full_name='criu_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='criu_resp.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='criu_resp.success', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dump', full_name='criu_resp.dump', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore', full_name='criu_resp.restore', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify', full_name='criu_resp.notify', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps', full_name='criu_resp.ps', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cr_errno', full_name='criu_resp.cr_errno', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='criu_resp.features', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cr_errmsg', full_name='criu_resp.cr_errmsg', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='criu_resp.version', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='criu_resp.status', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2372,
)


_CRIU_VERSION = _descriptor.Descriptor(
  name='criu_version',
  full_name='criu_version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major_number', full_name='criu_version.major_number', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor_number', full_name='criu_version.minor_number', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gitid', full_name='criu_version.gitid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sublevel', full_name='criu_version.sublevel', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='criu_version.extra', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='criu_version.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2374,
  serialized_end=2494,
)

_CRIU_OPTS.fields_by_name['ps'].message_type = _CRIU_PAGE_SERVER_INFO
_CRIU_OPTS.fields_by_name['veths'].message_type = _CRIU_VETH_PAIR
_CRIU_OPTS.fields_by_name['ext_mnt'].message_type = _EXT_MOUNT_MAP
_CRIU_OPTS.fields_by_name['cg_root'].message_type = _CGROUP_ROOT
_CRIU_OPTS.fields_by_name['inherit_fd'].message_type = _INHERIT_FD
_CRIU_OPTS.fields_by_name['unix_sk_ino'].message_type = _UNIX_SK
_CRIU_OPTS.fields_by_name['manage_cgroups_mode'].enum_type = _CRIU_CG_MODE
_CRIU_OPTS.fields_by_name['join_ns'].message_type = _JOIN_NAMESPACE
_CRIU_REQ.fields_by_name['type'].enum_type = _CRIU_REQ_TYPE
_CRIU_REQ.fields_by_name['opts'].message_type = _CRIU_OPTS
_CRIU_REQ.fields_by_name['features'].message_type = _CRIU_FEATURES
_CRIU_RESP.fields_by_name['type'].enum_type = _CRIU_REQ_TYPE
_CRIU_RESP.fields_by_name['dump'].message_type = _CRIU_DUMP_RESP
_CRIU_RESP.fields_by_name['restore'].message_type = _CRIU_RESTORE_RESP
_CRIU_RESP.fields_by_name['notify'].message_type = _CRIU_NOTIFY
_CRIU_RESP.fields_by_name['ps'].message_type = _CRIU_PAGE_SERVER_INFO
_CRIU_RESP.fields_by_name['features'].message_type = _CRIU_FEATURES
_CRIU_RESP.fields_by_name['version'].message_type = _CRIU_VERSION
DESCRIPTOR.message_types_by_name['criu_page_server_info'] = _CRIU_PAGE_SERVER_INFO
DESCRIPTOR.message_types_by_name['criu_veth_pair'] = _CRIU_VETH_PAIR
DESCRIPTOR.message_types_by_name['ext_mount_map'] = _EXT_MOUNT_MAP
DESCRIPTOR.message_types_by_name['join_namespace'] = _JOIN_NAMESPACE
DESCRIPTOR.message_types_by_name['inherit_fd'] = _INHERIT_FD
DESCRIPTOR.message_types_by_name['cgroup_root'] = _CGROUP_ROOT
DESCRIPTOR.message_types_by_name['unix_sk'] = _UNIX_SK
DESCRIPTOR.message_types_by_name['criu_opts'] = _CRIU_OPTS
DESCRIPTOR.message_types_by_name['criu_dump_resp'] = _CRIU_DUMP_RESP
DESCRIPTOR.message_types_by_name['criu_restore_resp'] = _CRIU_RESTORE_RESP
DESCRIPTOR.message_types_by_name['criu_notify'] = _CRIU_NOTIFY
DESCRIPTOR.message_types_by_name['criu_features'] = _CRIU_FEATURES
DESCRIPTOR.message_types_by_name['criu_req'] = _CRIU_REQ
DESCRIPTOR.message_types_by_name['criu_resp'] = _CRIU_RESP
DESCRIPTOR.message_types_by_name['criu_version'] = _CRIU_VERSION
DESCRIPTOR.enum_types_by_name['criu_cg_mode'] = _CRIU_CG_MODE
DESCRIPTOR.enum_types_by_name['criu_req_type'] = _CRIU_REQ_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

criu_page_server_info = _reflection.GeneratedProtocolMessageType('criu_page_server_info', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_PAGE_SERVER_INFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_page_server_info)
  ))
_sym_db.RegisterMessage(criu_page_server_info)

criu_veth_pair = _reflection.GeneratedProtocolMessageType('criu_veth_pair', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_VETH_PAIR,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_veth_pair)
  ))
_sym_db.RegisterMessage(criu_veth_pair)

ext_mount_map = _reflection.GeneratedProtocolMessageType('ext_mount_map', (_message.Message,), dict(
  DESCRIPTOR = _EXT_MOUNT_MAP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:ext_mount_map)
  ))
_sym_db.RegisterMessage(ext_mount_map)

join_namespace = _reflection.GeneratedProtocolMessageType('join_namespace', (_message.Message,), dict(
  DESCRIPTOR = _JOIN_NAMESPACE,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:join_namespace)
  ))
_sym_db.RegisterMessage(join_namespace)

inherit_fd = _reflection.GeneratedProtocolMessageType('inherit_fd', (_message.Message,), dict(
  DESCRIPTOR = _INHERIT_FD,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:inherit_fd)
  ))
_sym_db.RegisterMessage(inherit_fd)

cgroup_root = _reflection.GeneratedProtocolMessageType('cgroup_root', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_ROOT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_root)
  ))
_sym_db.RegisterMessage(cgroup_root)

unix_sk = _reflection.GeneratedProtocolMessageType('unix_sk', (_message.Message,), dict(
  DESCRIPTOR = _UNIX_SK,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:unix_sk)
  ))
_sym_db.RegisterMessage(unix_sk)

criu_opts = _reflection.GeneratedProtocolMessageType('criu_opts', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_OPTS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_opts)
  ))
_sym_db.RegisterMessage(criu_opts)

criu_dump_resp = _reflection.GeneratedProtocolMessageType('criu_dump_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_DUMP_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_dump_resp)
  ))
_sym_db.RegisterMessage(criu_dump_resp)

criu_restore_resp = _reflection.GeneratedProtocolMessageType('criu_restore_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_RESTORE_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_restore_resp)
  ))
_sym_db.RegisterMessage(criu_restore_resp)

criu_notify = _reflection.GeneratedProtocolMessageType('criu_notify', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_NOTIFY,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_notify)
  ))
_sym_db.RegisterMessage(criu_notify)

criu_features = _reflection.GeneratedProtocolMessageType('criu_features', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_FEATURES,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_features)
  ))
_sym_db.RegisterMessage(criu_features)

criu_req = _reflection.GeneratedProtocolMessageType('criu_req', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_REQ,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_req)
  ))
_sym_db.RegisterMessage(criu_req)

criu_resp = _reflection.GeneratedProtocolMessageType('criu_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_resp)
  ))
_sym_db.RegisterMessage(criu_resp)

criu_version = _reflection.GeneratedProtocolMessageType('criu_version', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_VERSION,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_version)
  ))
_sym_db.RegisterMessage(criu_version)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-opts.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-opts.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rsk-opts.proto\"\x8e\x03\n\rsk_opts_entry\x12\x11\n\tso_sndbuf\x18\x01 \x02(\r\x12\x11\n\tso_rcvbuf\x18\x02 \x02(\r\x12\x16\n\x0eso_snd_tmo_sec\x18\x03 \x02(\x04\x12\x17\n\x0fso_snd_tmo_usec\x18\x04 \x02(\x04\x12\x16\n\x0eso_rcv_tmo_sec\x18\x05 \x02(\x04\x12\x17\n\x0fso_rcv_tmo_usec\x18\x06 \x02(\x04\x12\x11\n\treuseaddr\x18\x07 \x01(\x08\x12\x13\n\x0bso_priority\x18\x08 \x01(\r\x12\x13\n\x0bso_rcvlowat\x18\t \x01(\r\x12\x0f\n\x07so_mark\x18\n \x01(\r\x12\x13\n\x0bso_passcred\x18\x0b \x01(\x08\x12\x12\n\nso_passsec\x18\x0c \x01(\x08\x12\x14\n\x0cso_dontroute\x18\r \x01(\x08\x12\x13\n\x0bso_no_check\x18\x0e \x01(\x08\x12\x14\n\x0cso_bound_dev\x18\x0f \x01(\t\x12\x11\n\tso_filter\x18\x10 \x03(\x06\x12\x14\n\x0cso_reuseport\x18\x11 \x01(\x08\x12\x14\n\x0cso_broadcast\x18\x12 \x01(\x08*6\n\x0bsk_shutdown\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x08\n\x04\x42OTH\x10\x03')
)

_SK_SHUTDOWN = _descriptor.EnumDescriptor(
  name='sk_shutdown',
  full_name='sk_shutdown',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOTH', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=418,
  serialized_end=472,
)
_sym_db.RegisterEnumDescriptor(_SK_SHUTDOWN)

sk_shutdown = enum_type_wrapper.EnumTypeWrapper(_SK_SHUTDOWN)
NONE = 0
READ = 1
WRITE = 2
BOTH = 3



_SK_OPTS_ENTRY = _descriptor.Descriptor(
  name='sk_opts_entry',
  full_name='sk_opts_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='so_sndbuf', full_name='sk_opts_entry.so_sndbuf', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_rcvbuf', full_name='sk_opts_entry.so_rcvbuf', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_snd_tmo_sec', full_name='sk_opts_entry.so_snd_tmo_sec', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_snd_tmo_usec', full_name='sk_opts_entry.so_snd_tmo_usec', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_rcv_tmo_sec', full_name='sk_opts_entry.so_rcv_tmo_sec', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_rcv_tmo_usec', full_name='sk_opts_entry.so_rcv_tmo_usec', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reuseaddr', full_name='sk_opts_entry.reuseaddr', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_priority', full_name='sk_opts_entry.so_priority', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_rcvlowat', full_name='sk_opts_entry.so_rcvlowat', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_mark', full_name='sk_opts_entry.so_mark', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_passcred', full_name='sk_opts_entry.so_passcred', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_passsec', full_name='sk_opts_entry.so_passsec', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_dontroute', full_name='sk_opts_entry.so_dontroute', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_no_check', full_name='sk_opts_entry.so_no_check', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_bound_dev', full_name='sk_opts_entry.so_bound_dev', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_filter', full_name='sk_opts_entry.so_filter', index=15,
      number=16, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_reuseport', full_name='sk_opts_entry.so_reuseport', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='so_broadcast', full_name='sk_opts_entry.so_broadcast', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=416,
)

DESCRIPTOR.message_types_by_name['sk_opts_entry'] = _SK_OPTS_ENTRY
DESCRIPTOR.enum_types_by_name['sk_shutdown'] = _SK_SHUTDOWN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sk_opts_entry = _reflection.GeneratedProtocolMessageType('sk_opts_entry', (_message.Message,), dict(
  DESCRIPTOR = _SK_OPTS_ENTRY,
  __module__ = 'sk_opts_pb2'
  # @@protoc_insertion_point(class_scope:sk_opts_entry)
  ))
_sym_db.RegisterMessage(sk_opts_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: file-lock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='file-lock.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0f\x66ile-lock.proto\"b\n\x0f\x66ile_lock_entry\x12\x0c\n\x04\x66lag\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0b\n\x03pid\x18\x03 \x02(\x05\x12\n\n\x02\x66\x64\x18\x04 \x02(\x05\x12\r\n\x05start\x18\x05 \x02(\x03\x12\x0b\n\x03len\x18\x06 \x02(\x03')
)




_FILE_LOCK_ENTRY = _descriptor.Descriptor(
  name='file_lock_entry',
  full_name='file_lock_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag', full_name='file_lock_entry.flag', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='file_lock_entry.type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='file_lock_entry.pid', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='file_lock_entry.fd', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='file_lock_entry.start', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='len', full_name='file_lock_entry.len', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19,
  serialized_end=117,
)

DESCRIPTOR.message_types_by_name['file_lock_entry'] = _FILE_LOCK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

file_lock_entry = _reflection.GeneratedProtocolMessageType('file_lock_entry', (_message.Message,), dict(
  DESCRIPTOR = _FILE_LOCK_ENTRY,
  __module__ = 'file_lock_pb2'
  # @@protoc_insertion_point(class_scope:file_lock_entry)
  ))
_sym_db.RegisterMessage(file_lock_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-s390.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-s390.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0f\x63ore-s390.proto\x1a\nopts.proto\"~\n\x14user_s390_regs_entry\x12\x10\n\x08psw_mask\x18\x01 \x02(\x04\x12\x10\n\x08psw_addr\x18\x02 \x02(\x04\x12\x0c\n\x04gprs\x18\x03 \x03(\x04\x12\x0c\n\x04\x61\x63rs\x18\x04 \x03(\r\x12\x11\n\torig_gpr2\x18\x05 \x02(\x04\x12\x13\n\x0bsystem_call\x18\x06 \x02(\r\"(\n\x18user_s390_vxrs_low_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\")\n\x19user_s390_vxrs_high_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"3\n\x16user_s390_fpregs_entry\x12\x0b\n\x03\x66pc\x18\x01 \x02(\r\x12\x0c\n\x04\x66prs\x18\x02 \x03(\x04\"%\n\x15user_s390_gs_cb_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"1\n\x12user_s390_ri_entry\x12\r\n\x05ri_on\x18\x01 \x02(\r\x12\x0c\n\x04regs\x18\x02 \x03(\x04\"\x80\x03\n\x10thread_info_s390\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12,\n\x06gpregs\x18\x02 \x02(\x0b\x32\x15.user_s390_regs_entryB\x05\xd2?\x02\x08\x01\x12.\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x17.user_s390_fpregs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x08vxrs_low\x18\x04 \x01(\x0b\x32\x19.user_s390_vxrs_low_entryB\x05\xd2?\x02\x08\x01\x12\x34\n\tvxrs_high\x18\x05 \x01(\x0b\x32\x1a.user_s390_vxrs_high_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_cb\x18\x06 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_bc\x18\x07 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12)\n\x05ri_cb\x18\x08 \x01(\x0b\x32\x13.user_s390_ri_entryB\x05\xd2?\x02\x08\x01')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_USER_S390_REGS_ENTRY = _descriptor.Descriptor(
  name='user_s390_regs_entry',
  full_name='user_s390_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='psw_mask', full_name='user_s390_regs_entry.psw_mask', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='psw_addr', full_name='user_s390_regs_entry.psw_addr', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gprs', full_name='user_s390_regs_entry.gprs', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acrs', full_name='user_s390_regs_entry.acrs', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_gpr2', full_name='user_s390_regs_entry.orig_gpr2', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_call', full_name='user_s390_regs_entry.system_call', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=157,
)


_USER_S390_VXRS_LOW_ENTRY = _descriptor.Descriptor(
  name='user_s390_vxrs_low_entry',
  full_name='user_s390_vxrs_low_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_vxrs_low_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=199,
)


_USER_S390_VXRS_HIGH_ENTRY = _descriptor.Descriptor(
  name='user_s390_vxrs_high_entry',
  full_name='user_s390_vxrs_high_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_vxrs_high_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=242,
)


_USER_S390_FPREGS_ENTRY = _descriptor.Descriptor(
  name='user_s390_fpregs_entry',
  full_name='user_s390_fpregs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpc', full_name='user_s390_fpregs_entry.fpc', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fprs', full_name='user_s390_fpregs_entry.fprs', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=295,
)


_USER_S390_GS_CB_ENTRY = _descriptor.Descriptor(
  name='user_s390_gs_cb_entry',
  full_name='user_s390_gs_cb_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_gs_cb_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=334,
)


_USER_S390_RI_ENTRY = _descriptor.Descriptor(
  name='user_s390_ri_entry',
  full_name='user_s390_ri_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ri_on', full_name='user_s390_ri_entry.ri_on', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_ri_entry.regs', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=385,
)


_THREAD_INFO_S390 = _descriptor.Descriptor(
  name='thread_info_s390',
  full_name='thread_info_s390',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_s390.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_s390.gpregs', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpregs', full_name='thread_info_s390.fpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vxrs_low', full_name='thread_info_s390.vxrs_low', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vxrs_high', full_name='thread_info_s390.vxrs_high', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_cb', full_name='thread_info_s390.gs_cb', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_bc', full_name='thread_info_s390.gs_bc', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ri_cb', full_name='thread_info_s390.ri_cb', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=772,
)

_THREAD_INFO_S390.fields_by_name['gpregs'].message_type = _USER_S390_REGS_ENTRY
_THREAD_INFO_S390.fields_by_name['fpregs'].message_type = _USER_S390_FPREGS_ENTRY
_THREAD_INFO_S390.fields_by_name['vxrs_low'].message_type = _USER_S390_VXRS_LOW_ENTRY
_THREAD_INFO_S390.fields_by_name['vxrs_high'].message_type = _USER_S390_VXRS_HIGH_ENTRY
_THREAD_INFO_S390.fields_by_name['gs_cb'].message_type = _USER_S390_GS_CB_ENTRY
_THREAD_INFO_S390.fields_by_name['gs_bc'].message_type = _USER_S390_GS_CB_ENTRY
_THREAD_INFO_S390.fields_by_name['ri_cb'].message_type = _USER_S390_RI_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_regs_entry'] = _USER_S390_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_vxrs_low_entry'] = _USER_S390_VXRS_LOW_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_vxrs_high_entry'] = _USER_S390_VXRS_HIGH_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_fpregs_entry'] = _USER_S390_FPREGS_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_gs_cb_entry'] = _USER_S390_GS_CB_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_ri_entry'] = _USER_S390_RI_ENTRY
DESCRIPTOR.message_types_by_name['thread_info_s390'] = _THREAD_INFO_S390
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_s390_regs_entry = _reflection.GeneratedProtocolMessageType('user_s390_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_REGS_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_regs_entry)
  ))
_sym_db.RegisterMessage(user_s390_regs_entry)

user_s390_vxrs_low_entry = _reflection.GeneratedProtocolMessageType('user_s390_vxrs_low_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_VXRS_LOW_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_vxrs_low_entry)
  ))
_sym_db.RegisterMessage(user_s390_vxrs_low_entry)

user_s390_vxrs_high_entry = _reflection.GeneratedProtocolMessageType('user_s390_vxrs_high_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_VXRS_HIGH_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_vxrs_high_entry)
  ))
_sym_db.RegisterMessage(user_s390_vxrs_high_entry)

user_s390_fpregs_entry = _reflection.GeneratedProtocolMessageType('user_s390_fpregs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_FPREGS_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_fpregs_entry)
  ))
_sym_db.RegisterMessage(user_s390_fpregs_entry)

user_s390_gs_cb_entry = _reflection.GeneratedProtocolMessageType('user_s390_gs_cb_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_GS_CB_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_gs_cb_entry)
  ))
_sym_db.RegisterMessage(user_s390_gs_cb_entry)

user_s390_ri_entry = _reflection.GeneratedProtocolMessageType('user_s390_ri_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_RI_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_ri_entry)
  ))
_sym_db.RegisterMessage(user_s390_ri_entry)

thread_info_s390 = _reflection.GeneratedProtocolMessageType('thread_info_s390', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_S390,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_s390)
  ))
_sym_db.RegisterMessage(thread_info_s390)


_THREAD_INFO_S390.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_S390.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_S390.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['fpregs'].has_options = True
_THREAD_INFO_S390.fields_by_name['fpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['vxrs_low'].has_options = True
_THREAD_INFO_S390.fields_by_name['vxrs_low']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['vxrs_high'].has_options = True
_THREAD_INFO_S390.fields_by_name['vxrs_high']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gs_cb'].has_options = True
_THREAD_INFO_S390.fields_by_name['gs_cb']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gs_bc'].has_options = True
_THREAD_INFO_S390.fields_by_name['gs_bc']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['ri_cb'].has_options = True
_THREAD_INFO_S390.fields_by_name['ri_cb']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ext-file.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ext-file.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0e\x65xt-file.proto\x1a\nfown.proto\"7\n\x0e\x65xt_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry')
  ,
  dependencies=[fown__pb2.DESCRIPTOR,])




_EXT_FILE_ENTRY = _descriptor.Descriptor(
  name='ext_file_entry',
  full_name='ext_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ext_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='ext_file_entry.fown', index=1,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=85,
)

_EXT_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
DESCRIPTOR.message_types_by_name['ext_file_entry'] = _EXT_FILE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ext_file_entry = _reflection.GeneratedProtocolMessageType('ext_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _EXT_FILE_ENTRY,
  __module__ = 'ext_file_pb2'
  # @@protoc_insertion_point(class_scope:ext_file_entry)
  ))
_sym_db.RegisterMessage(ext_file_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: siginfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='siginfo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rsiginfo.proto\" \n\rsiginfo_entry\x12\x0f\n\x07siginfo\x18\x01 \x02(\x0c\"5\n\x12signal_queue_entry\x12\x1f\n\x07signals\x18\x01 \x03(\x0b\x32\x0e.siginfo_entry')
)




_SIGINFO_ENTRY = _descriptor.Descriptor(
  name='siginfo_entry',
  full_name='siginfo_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='siginfo', full_name='siginfo_entry.siginfo', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17,
  serialized_end=49,
)


_SIGNAL_QUEUE_ENTRY = _descriptor.Descriptor(
  name='signal_queue_entry',
  full_name='signal_queue_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='signal_queue_entry.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=104,
)

_SIGNAL_QUEUE_ENTRY.fields_by_name['signals'].message_type = _SIGINFO_ENTRY
DESCRIPTOR.message_types_by_name['siginfo_entry'] = _SIGINFO_ENTRY
DESCRIPTOR.message_types_by_name['signal_queue_entry'] = _SIGNAL_QUEUE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

siginfo_entry = _reflection.GeneratedProtocolMessageType('siginfo_entry', (_message.Message,), dict(
  DESCRIPTOR = _SIGINFO_ENTRY,
  __module__ = 'siginfo_pb2'
  # @@protoc_insertion_point(class_scope:siginfo_entry)
  ))
_sym_db.RegisterMessage(siginfo_entry)

signal_queue_entry = _reflection.GeneratedProtocolMessageType('signal_queue_entry', (_message.Message,), dict(
  DESCRIPTOR = _SIGNAL_QUEUE_ENTRY,
  __module__ = 'siginfo_pb2'
  # @@protoc_insertion_point(class_scope:signal_queue_entry)
  ))
_sym_db.RegisterMessage(signal_queue_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sit.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tsit.proto\x1a\nopts.proto\"\xc9\x02\n\tsit_entry\x12\x0c\n\x04link\x18\x01 \x01(\r\x12\x14\n\x05local\x18\x02 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x15\n\x06remote\x18\x03 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x0b\n\x03ttl\x18\x04 \x01(\r\x12\x0b\n\x03tos\x18\x05 \x01(\r\x12\x10\n\x08pmtudisc\x18\x06 \x01(\x08\x12\r\n\x05proto\x18\x07 \x01(\r\x12\r\n\x05\x66lags\x18\x08 \x01(\r\x12\x12\n\nencap_type\x18\t \x01(\r\x12\x13\n\x0b\x65ncap_flags\x18\n \x01(\r\x12\x13\n\x0b\x65ncap_sport\x18\x0b \x01(\r\x12\x13\n\x0b\x65ncap_dport\x18\x0c \x01(\r\x12\x14\n\x0crd_prefixlen\x18\r \x01(\r\x12\x18\n\trd_prefix\x18\x0e \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x0frelay_prefixlen\x18\x0f \x01(\r\x12\x1b\n\x0crelay_prefix\x18\x10 \x03(\rB\x05\xd2?\x02\x10\x01')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_SIT_ENTRY = _descriptor.Descriptor(
  name='sit_entry',
  full_name='sit_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='sit_entry.link', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local', full_name='sit_entry.local', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote', full_name='sit_entry.remote', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='sit_entry.ttl', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tos', full_name='sit_entry.tos', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pmtudisc', full_name='sit_entry.pmtudisc', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proto', full_name='sit_entry.proto', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='sit_entry.flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_type', full_name='sit_entry.encap_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_flags', full_name='sit_entry.encap_flags', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_sport', full_name='sit_entry.encap_sport', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_dport', full_name='sit_entry.encap_dport', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rd_prefixlen', full_name='sit_entry.rd_prefixlen', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rd_prefix', full_name='sit_entry.rd_prefix', index=13,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay_prefixlen', full_name='sit_entry.relay_prefixlen', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay_prefix', full_name='sit_entry.relay_prefix', index=15,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=355,
)

DESCRIPTOR.message_types_by_name['sit_entry'] = _SIT_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sit_entry = _reflection.GeneratedProtocolMessageType('sit_entry', (_message.Message,), dict(
  DESCRIPTOR = _SIT_ENTRY,
  __module__ = 'sit_pb2'
  # @@protoc_insertion_point(class_scope:sit_entry)
  ))
_sym_db.RegisterMessage(sit_entry)


_SIT_ENTRY.fields_by_name['local'].has_options = True
_SIT_ENTRY.fields_by_name['local']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['remote'].has_options = True
_SIT_ENTRY.fields_by_name['remote']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['rd_prefix'].has_options = True
_SIT_ENTRY.fields_by_name['rd_prefix']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['relay_prefix'].has_options = True
_SIT_ENTRY.fields_by_name['relay_prefix']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-packet.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-packet.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0fsk-packet.proto\")\n\tscm_entry\x12\x0c\n\x04type\x18\x01 \x02(\r\x12\x0e\n\x06rights\x18\x02 \x03(\r\"J\n\x0fsk_packet_entry\x12\x0e\n\x06id_for\x18\x01 \x02(\r\x12\x0e\n\x06length\x18\x02 \x02(\r\x12\x17\n\x03scm\x18\x04 \x03(\x0b\x32\n.scm_entry')
)




_SCM_ENTRY = _descriptor.Descriptor(
  name='scm_entry',
  full_name='scm_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='scm_entry.type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rights', full_name='scm_entry.rights', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19,
  serialized_end=60,
)


_SK_PACKET_ENTRY = _descriptor.Descriptor(
  name='sk_packet_entry',
  full_name='sk_packet_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_for', full_name='sk_packet_entry.id_for', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='sk_packet_entry.length', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scm', full_name='sk_packet_entry.scm', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=136,
)

_SK_PACKET_ENTRY.fields_by_name['scm'].message_type = _SCM_ENTRY
DESCRIPTOR.message_types_by_name['scm_entry'] = _SCM_ENTRY
DESCRIPTOR.message_types_by_name['sk_packet_entry'] = _SK_PACKET_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

scm_entry = _reflection.GeneratedProtocolMessageType('scm_entry', (_message.Message,), dict(
  DESCRIPTOR = _SCM_ENTRY,
  __module__ = 'sk_packet_pb2'
  # @@protoc_insertion_point(class_scope:scm_entry)
  ))
_sym_db.RegisterMessage(scm_entry)

sk_packet_entry = _reflection.GeneratedProtocolMessageType('sk_packet_entry', (_message.Message,), dict(
  DESCRIPTOR = _SK_PACKET_ENTRY,
  __module__ = 'sk_packet_pb2'
  # @@protoc_insertion_point(class_scope:sk_packet_entry)
  ))
_sym_db.RegisterMessage(sk_packet_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: remap-file-path.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='remap-file-path.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x15remap-file-path.proto\"[\n\x15remap_file_path_entry\x12\x0f\n\x07orig_id\x18\x01 \x02(\r\x12\x10\n\x08remap_id\x18\x02 \x02(\r\x12\x1f\n\nremap_type\x18\x03 \x01(\x0e\x32\x0b.remap_type*/\n\nremap_type\x12\n\n\x06LINKED\x10\x00\x12\t\n\x05GHOST\x10\x01\x12\n\n\x06PROCFS\x10\x02')
)

_REMAP_TYPE = _descriptor.EnumDescriptor(
  name='remap_type',
  full_name='remap_type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINKED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GHOST', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCFS', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=118,
  serialized_end=165,
)
_sym_db.RegisterEnumDescriptor(_REMAP_TYPE)

remap_type = enum_type_wrapper.EnumTypeWrapper(_REMAP_TYPE)
LINKED = 0
GHOST = 1
PROCFS = 2



_REMAP_FILE_PATH_ENTRY = _descriptor.Descriptor(
  name='remap_file_path_entry',
  full_name='remap_file_path_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orig_id', full_name='remap_file_path_entry.orig_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remap_id', full_name='remap_file_path_entry.remap_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remap_type', full_name='remap_file_path_entry.remap_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=116,
)

_REMAP_FILE_PATH_ENTRY.fields_by_name['remap_type'].enum_type = _REMAP_TYPE
DESCRIPTOR.message_types_by_name['remap_file_path_entry'] = _REMAP_FILE_PATH_ENTRY
DESCRIPTOR.enum_types_by_name['remap_type'] = _REMAP_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

remap_file_path_entry = _reflection.GeneratedProtocolMessageType('remap_file_path_entry', (_message.Message,), dict(
  DESCRIPTOR = _REMAP_FILE_PATH_ENTRY,
  __module__ = 'remap_file_path_pb2'
  # @@protoc_insertion_point(class_scope:remap_file_path_entry)
  ))
_sym_db.RegisterMessage(remap_file_path_entry)


# @@protoc_insertion_point(module_scope)
